@@ -1,11 +1,9 @@
 from photutils.centroids import centroid_sources, centroid_2dg, centroid_quadratic, centroid_com
 from .. import Block
-from prose.block import _NeedStars
 import numpy as np
 from os import path
 from prose import CONFIG
 from .psf import cutouts
-from ..utils import register_args
 import warnings
 from astropy.utils.exceptions import AstropyUserWarning
 
@@ -28,7 +26,7 @@ except ModuleNotFoundError:
     TF_LOADED = True
 
 
-class PhotutilsCentroid(_NeedStars):
+class PhotutilsCentroid(Block):
 
     
     def __init__(self, centroid_func, limit=None, cutout=21, **kwargs):
@@ -68,9 +66,9 @@ class PhotutilsCentroid(_NeedStars):
         in_limit = np.linalg.norm(image.stars_coords - stars_coords, axis=1) < self.limit
         image.stars_coords[in_limit] = stars_coords[in_limit]
 
-    @staticmethod
-    def citations():
-        return "photutils", "numpy"
+    @property
+    def citations(self):
+        return "photutils"
 
 class COM(PhotutilsCentroid):
     """Centroiding using ``photutils.centroids.centroid_com``
@@ -173,10 +171,9 @@ class CNNCentroid(Block):
             # change image.stars_coords
             image.stars_coords[stars_in] = aligned_stars_coords
 
-    @staticmethod
-    def citations():
-        return "tensorflow", "numpy"
-
+    @property
+    def citations(self):
+        return "tensorflow"
 
 class BalletCentroid(CNNCentroid):
     """Centroiding with  `ballet <https://github.com/lgrcia/ballet>`_.
