@@ -201,7 +201,9 @@ class ApertureFluxes:
 
     @property
     def target(self):
-        return self.xarray.attrs['target']
+        return self.xarray.attrs.get('target', -1)
+        #TODO: target not set error over all Observation function using target
+
 
     @target.setter
     def target(self, value):
@@ -211,7 +213,8 @@ class ApertureFluxes:
 
     @property
     def aperture(self):
-        return self.xarray.aperture
+        return self.xarray.attr.get('aperture', -1)
+        #TODO: aperture not set error over all Observation 
 
     @aperture.setter
     def aperture(self, value):
@@ -440,7 +443,7 @@ class ApertureFluxes:
         if not inplace:
             return new_self
 
-    def broeg2005(self, inplace=True, cut=None, nans=False):
+    def broeg2005(self, inplace=True, cut=True, nans=False):
         """
         The Broeg et al. 2005 differential photometry algorithm
 
